NextSearch class

Constructors

NextSearch({required String query, String mode = 'search', String params = '', String? browseId, String? ctoken})

Properties

browseId String?
getter/setter pair
ctoken String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mode String
getter/setter pair
params String
getter/setter pair
query String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(Map<String, dynamic> data) NextSearch