PlayableItem class

Constructors

PlayableItem({required String id, required TextComponentDetail title, required TextComponentDetail author, required String thumbnail, required int duration, Uri? streamUrl})

Properties

author TextComponentDetail
getter/setter pair
duration int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamUrl Uri?
getter/setter pair
thumbnail String
getter/setter pair
title TextComponentDetail
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(Map<String, dynamic> data) PlayableItem