Playlist class

Constructors

Playlist({required String id, required TextComponentDetail title, required List<TextComponentDetail> subtitle, required List<TextComponentDetail> secondSubtitle, required List<TextComponentDetail> description, required String thumbnail, required List<Content> contents, NextSearch? nextSearch})

Properties

contents List<Content>
getter/setter pair
description List<TextComponentDetail>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
nextSearch NextSearch?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondSubtitle List<TextComponentDetail>
getter/setter pair
subtitle List<TextComponentDetail>
getter/setter pair
thumbnail String
getter/setter pair
title TextComponentDetail
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(Map<String, dynamic> data) Playlist