Profile class
Constructors
-
Profile({required String id, required String name, required List<
TextComponentDetail> about, required String image, required List<CategorizedContent> contents})
Properties
-
about
↔ List<
TextComponentDetail> -
getter/setter pair
-
contents
↔ List<
CategorizedContent> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- image ↔ String
-
getter/setter pair
- name ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited