Queue class

Constructors

Queue({required int index, required String playlistId, required CurrentLyrics lyrics, required List<Content> queue})

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
final
lyrics CurrentLyrics
final
playlistId String
final
queue List<Content>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited