Queue class

Constructors

Queue({required int index, required String playlistId, required List<Content> queue})

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
getter/setter pair
playlistId String
getter/setter pair
queue List<Content>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(Map<String, dynamic> data) Queue